(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/material'), require('@angular/animations')) :
    typeof define === 'function' && define.amd ? define('angular-material_8-datepicker', ['exports', '@angular/core', '@angular/common', '@angular/material', '@angular/animations'], factory) :
    (global = global || self, factory(global['angular-material_8-datepicker'] = {}, global.ng.core, global.ng.common, global.ng.material, global.ng.animations));
}(this, function (exports, core, common, material, animations) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
    }

    var CalendarService = /** @class */ (function () {
        function CalendarService() {
            this.firstWeekDay = 0; // 0 = sunday
        }
        CalendarService.prototype.weekStartDate = function (date) {
            var startDate = new Date(date.getTime());
            while (startDate.getDay() !== this.firstWeekDay) {
                startDate.setDate(startDate.getDate() - 1);
            }
            return startDate;
        };
        CalendarService.prototype.monthDates = function (year, month, dayFormatter, weekFormatter) {
            if (dayFormatter === void 0) { dayFormatter = null; }
            if (weekFormatter === void 0) { weekFormatter = null; }
            if ((typeof year !== "number") || (year < 1970)) {
                throw ('year must be a number >= 1970');
            }
            if ((typeof month !== "number") || (month < 0) || (month > 11)) {
                throw ('month must be a number (Jan is 0)');
            }
            var weeks = [], week = [], i = 0, date = this.weekStartDate(new Date(year, month, 1));
            do {
                for (i = 0; i < 7; i++) {
                    week.push(dayFormatter ? dayFormatter(date) : date);
                    date = new Date(date.getTime());
                    date.setDate(date.getDate() + 1);
                }
                weeks.push(weekFormatter ? weekFormatter(week) : week);
                week = [];
            } while ((date.getMonth() <= month) && (date.getFullYear() === year));
            return weeks;
        };
        CalendarService.prototype.monthDays = function (year, month) {
            var getDayOrZero = function getDayOrZero(date) {
                return date.getMonth() === month ? date : 0;
            };
            return this.monthDates(year, month, getDayOrZero);
        };
        CalendarService.prototype.monthText = function (year, month) {
            if (typeof year === "undefined") {
                var now = new Date();
                year = now.getFullYear();
                month = now.getMonth();
            }
            var getDayOrBlank = function getDayOrBlank(date) {
                var s = date.getMonth() === month ? date.getDate().toString() : "  ";
                while (s.length < 2)
                    s = " " + s;
                return s;
            };
            var weeks = this.monthDates(year, month, getDayOrBlank, function (week) { return week.join(" "); });
            return weeks.join("\n");
        };
        CalendarService = __decorate([
            core.Injectable(),
            __metadata("design:paramtypes", [])
        ], CalendarService);
        return CalendarService;
    }());
    // unclear what this actually does...
    // const months = "JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC".split(" ");
    // for (var i=0; i<months.length; i++) {
    //     Calendar[months[i]] = i;
    // }
    /*!
     * calendar: a port of the calendar module from Python
     * Copyright(c) 2011 Luciano Ramalho <luciano@ramalho.org>
     * MIT Licensed
     */

    var LANG_DE = {
        weekDays: [
            {
                letter: "S",
                short: "So.",
                full: "Sonntag"
            },
            {
                letter: "M",
                short: "Mo.",
                full: "Montag"
            },
            {
                letter: "D",
                short: "Di.",
                full: "Dienstag"
            },
            {
                letter: "M",
                short: "Mi.",
                full: "Mittwoch"
            },
            {
                letter: "D",
                short: "Do.",
                full: "Donnerstag"
            },
            {
                letter: "F",
                short: "Fr.",
                full: "Freitag"
            },
            {
                letter: "S",
                short: "Sa.",
                full: "Samstag"
            }
        ],
        months: [
            {
                short: "Jan.",
                full: "Januar"
            },
            {
                short: "Feb.",
                full: "Februar"
            },
            {
                short: "März",
                full: "März"
            },
            {
                short: "Apr.",
                full: "April"
            },
            {
                short: "Mai",
                full: "Mai"
            },
            {
                short: "Juni",
                full: "Juni"
            },
            {
                short: "Juli",
                full: "Juli"
            },
            {
                short: "Aug.",
                full: "August"
            },
            {
                short: "Sep.",
                full: "September"
            },
            {
                short: "Okt.",
                full: "Oktober"
            },
            {
                short: "Nov.",
                full: "November"
            },
            {
                short: "Dez.",
                full: "Dezember"
            }
        ]
    };

    var CalendarComponent = /** @class */ (function () {
        function CalendarComponent(calendarService) {
            this.dateChange = new core.EventEmitter();
            this.cancel = new core.EventEmitter();
            this.submit = new core.EventEmitter();
            this.today = new Date();
            this.calendarService = calendarService;
            this.dayNames = LANG_DE.weekDays;
            this.monthNames = LANG_DE.months;
        }
        Object.defineProperty(CalendarComponent.prototype, "date", {
            get: function () {
                return this.dateVal;
            },
            set: function (val) {
                this.dateVal = val;
                this.dateChange.emit(val);
                this.updateDate(val);
            },
            enumerable: true,
            configurable: true
        });
        CalendarComponent.prototype.ngOnInit = function () {
            this.date = new Date();
        };
        CalendarComponent.prototype.updateDate = function (date) {
            this.currentMonthNumber = date.getMonth();
            this.currentMonth = this.monthNames[this.currentMonthNumber];
            this.currentYear = date.getFullYear();
            this.currentDay = date.getDate();
            this.currentDayOfWeek = this.dayNames[date.getDay()];
            this.updateDisplay(this.currentYear, this.currentMonthNumber);
        };
        CalendarComponent.prototype.updateDisplay = function (year, month) {
            var calendarArray = this.calendarService.monthDays(year, month);
            this.displayDays = [].concat.apply([], calendarArray);
            this.displayMonthNumber = month;
            this.displayMonth = this.monthNames[month];
            this.displayYear = year;
        };
        CalendarComponent.prototype.equalsDate = function (date1, date2) {
            try {
                return date1.getFullYear() === date2.getFullYear() && date1.getMonth() === date2.getMonth() && date1.getDate() === date2.getDate();
            }
            catch (error) {
                return false;
            }
        };
        CalendarComponent.prototype.getDayBackgroundColor = function (day) {
            if (this.equalsDate(day, this.date)) {
                return 'day-background-selected';
            }
            else {
                return 'day-background-normal';
            }
        };
        CalendarComponent.prototype.getDayForegroundColor = function (day) {
            if (this.equalsDate(day, this.date)) {
                return 'day-foreground-selected';
            }
            else if (this.equalsDate(day, this.today)) {
                return 'day-foreground-today';
            }
            else {
                return 'day-foreground-normal';
            }
        };
        CalendarComponent.prototype.onToday = function () {
            this.date = this.today;
        };
        CalendarComponent.prototype.onPrevMonth = function () {
            if (this.displayMonthNumber > 0) {
                this.updateDisplay(this.displayYear, this.displayMonthNumber - 1);
            }
            else {
                this.updateDisplay(this.displayYear - 1, 11);
            }
            this.triggerAnimation('left');
        };
        CalendarComponent.prototype.onNextMonth = function () {
            if (this.displayMonthNumber < 11) {
                this.updateDisplay(this.displayYear, this.displayMonthNumber + 1);
            }
            else {
                this.updateDisplay(this.displayYear + 1, 0);
            }
            this.triggerAnimation('right');
        };
        CalendarComponent.prototype.onSelectDate = function (date) {
            this.date = date;
        };
        CalendarComponent.prototype.onCancel = function () {
            this.cancel.emit();
        };
        CalendarComponent.prototype.onOk = function () {
            this.submit.emit(this.date);
        };
        CalendarComponent.prototype.triggerAnimation = function (direction) {
            var _this = this;
            this.animate = direction;
            setTimeout(function () { return _this.animate = 'reset'; }, 230);
        };
        __decorate([
            core.Output(),
            __metadata("design:type", Object)
        ], CalendarComponent.prototype, "dateChange", void 0);
        __decorate([
            core.Input(),
            __metadata("design:type", Date),
            __metadata("design:paramtypes", [Date])
        ], CalendarComponent.prototype, "date", null);
        __decorate([
            core.Output(),
            __metadata("design:type", Object)
        ], CalendarComponent.prototype, "cancel", void 0);
        __decorate([
            core.Output(),
            __metadata("design:type", Object)
        ], CalendarComponent.prototype, "submit", void 0);
        CalendarComponent = __decorate([
            core.Component({
                selector: 'md-calendar',
                template: "<div class=\"header\">\n    <div class=\"year\">{{ currentYear }}</div>\n    <div class=\"date\">{{ currentDayOfWeek.short }}, {{ currentDay}}. {{ currentMonth.short }}</div>\n</div>\n<div class=\"nav\">\n    <button mat-icon-button class=\"left\" (click)=\"onPrevMonth()\">\n        <mat-icon>chevron_left</mat-icon>\n    </button>\n    <div class=\"title\">\n        <div [@calendarAnimation]=\"animate\">{{ displayMonth.full }} {{ displayYear }}</div>\n    </div>\n    <button mat-icon-button class=\"right\" (click)=\"onNextMonth()\">\n        <mat-icon>chevron_right</mat-icon>\n    </button>\n</div>\n<div class=\"content\">\n    <div class=\"labels\">\n        <div class=\"label\" *ngFor=\"let day of dayNames\">\n            {{ day.letter }}\n        </div>\n    </div>\n    <div [@calendarAnimation]=\"animate\" class=\"month\">\n        <div *ngFor=\"let day of displayDays\" class=\"day\" (click)=\"onSelectDate(day)\" [ngClass]=\"getDayBackgroundColor(day)\">\n            <span *ngIf=\"day != 0\" [ngClass]=\"getDayForegroundColor(day)\">\n                {{ day.getDate() }}\n              </span>\n        </div>\n    </div>\n</div>\n<div class=\"footer\">\n    <a mat-button (click)=\"onToday()\">Today</a>\n    <a mat-button (click)=\"onCancel()\">Cancel</a>\n    <a mat-button (click)=\"onOk()\">Ok</a>\n</div>\n",
                animations: [
                    animations.trigger('calendarAnimation', [
                        animations.transition('* => left', [
                            animations.animate('0.225s ease-in-out', animations.keyframes([
                                animations.style({ transform: 'translateX(105%)', offset: 0.5 }),
                                animations.style({ transform: 'translateX(-130%)', offset: 0.51 }),
                                animations.style({ transform: 'translateX(0)', offset: 1 }),
                            ]))
                        ]),
                        animations.transition('* => right', [
                            animations.animate('0.225s ease-in-out', animations.keyframes([
                                animations.style({ transform: 'translateX(-105%)', offset: 0.5 }),
                                animations.style({ transform: 'translateX(130%)', offset: 0.51 }),
                                animations.style({ transform: 'translateX(0)', offset: 1 })
                            ]))
                        ])
                    ])
                ],
                styles: [".content,.footer,.header,.nav{font-family:Roboto,\"Segoe UI\",\"Helvetica Neue\",sans-serif}.header{padding:16px}.header .year{color:rgba(255,255,255,.7);font-size:14px;font-weight:500;margin-bottom:4px}.header .date{color:#fff;font-size:32px;font-weight:600}.nav{padding-top:8px;padding-bottom:8px;min-height:40px;overflow:hidden;position:relative}.nav .left{position:absolute;left:8px;z-index:100}.nav .right{position:absolute;right:8px;z-index:100}.nav .title{position:absolute;left:0;right:0;line-height:40px;text-align:center;font-size:14px;font-weight:600;overflow:hidden;z-index:10}.content{font-size:13px;padding-left:8px;padding-right:8px;width:18.2em;height:18.2em;overflow:hidden}.content .labels{display:-webkit-box;display:flex;-webkit-box-pack:center;justify-content:center;width:100%}.content .label{display:inline-block;width:2.2em;height:2.2em;margin:0 .2em;line-height:2.2em;text-align:center;color:rgba(0,0,0,.4)}.content .month{display:-webkit-box;display:flex;flex-flow:wrap;-webkit-box-pack:center;justify-content:center}.content .day{display:inline-block;width:2.2em;height:2.2em;margin:0 .2em .4em;border-radius:2.2em;line-height:2.2em;text-align:center;-webkit-transition:.37s;transition:.37s;cursor:pointer}.footer{text-align:right;padding:8px 8px 16px}.footer [md-button]{min-width:0;font-weight:600;text-transform:uppercase}"]
            }),
            __metadata("design:paramtypes", [CalendarService])
        ], CalendarComponent);
        return CalendarComponent;
    }());

    var DatePickerComponent = /** @class */ (function () {
        function DatePickerComponent(dialog) {
            this.dateChange = new core.EventEmitter();
            this.dialog = dialog;
            this.dayNames = LANG_DE.weekDays;
            this.monthNames = LANG_DE.months;
        }
        Object.defineProperty(DatePickerComponent.prototype, "date", {
            get: function () {
                return this.dateVal;
            },
            set: function (val) {
                this.dateVal = val;
                this.dateChange.emit(val);
                this.formattedDate = this.formatDate(val);
            },
            enumerable: true,
            configurable: true
        });
        DatePickerComponent.prototype.ngOnInit = function () {
            if (this.date === undefined) {
                this.date = new Date();
            }
        };
        DatePickerComponent.prototype.openDialog = function () {
            var _this = this;
            var ref = this.dialog.open(CalendarComponent);
            // Workaround to update style of dialog which sits outside of the component
            var containerDiv = ref._overlayRef._pane.children[0];
            containerDiv.style['padding'] = '0';
            ref.componentInstance.submit.subscribe(function (result) {
                _this.date = result;
                ref.close();
            });
            ref.componentInstance.cancel.subscribe(function (result) {
                ref.close();
            });
        };
        DatePickerComponent.prototype.formatDate = function (date) {
            if (date === undefined) {
                return;
            }
            var dayOfWeek = this.dayNames[date.getDay()].short;
            var dayOfMonth = date.getDate();
            var month = this.monthNames[date.getMonth()].short;
            var year = date.getFullYear();
            return dayOfWeek + ", " + dayOfMonth + ". " + month + " " + year;
        };
        __decorate([
            core.Output(),
            __metadata("design:type", Object)
        ], DatePickerComponent.prototype, "dateChange", void 0);
        __decorate([
            core.Input(),
            __metadata("design:type", Date),
            __metadata("design:paramtypes", [Date])
        ], DatePickerComponent.prototype, "date", null);
        DatePickerComponent = __decorate([
            core.Component({
                selector: 'md-datepicker',
                template: "<span class=\"selected-date\" (click)=\"openDialog()\">{{formattedDate}}</span>",
                styles: [""]
            }),
            __metadata("design:paramtypes", [material.MatDialog])
        ], DatePickerComponent);
        return DatePickerComponent;
    }());

    var DatePickerModule = /** @class */ (function () {
        function DatePickerModule() {
        }
        DatePickerModule = __decorate([
            core.NgModule({
                declarations: [
                    DatePickerComponent,
                    CalendarComponent
                ],
                imports: [
                    common.CommonModule,
                    material.MatIconModule,
                    material.MatButtonModule,
                    material.MatDialogModule
                ],
                exports: [
                    DatePickerComponent
                ],
                providers: [
                    CalendarService
                ],
                entryComponents: [
                    CalendarComponent
                ]
            })
        ], DatePickerModule);
        return DatePickerModule;
    }());

    exports.DatePickerModule = DatePickerModule;
    exports.ɵa = DatePickerComponent;
    exports.ɵb = CalendarComponent;
    exports.ɵc = CalendarService;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=angular-material_8-datepicker.umd.js.map
