import { __decorate, __metadata } from 'tslib';
import { Injectable, EventEmitter, Output, Input, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatDialog, MatIconModule, MatButtonModule, MatDialogModule } from '@angular/material';
import { trigger, transition, animate, keyframes, style } from '@angular/animations';

let CalendarService = class CalendarService {
    constructor() {
        this.firstWeekDay = 0; // 0 = sunday
    }
    weekStartDate(date) {
        var startDate = new Date(date.getTime());
        while (startDate.getDay() !== this.firstWeekDay) {
            startDate.setDate(startDate.getDate() - 1);
        }
        return startDate;
    }
    monthDates(year, month, dayFormatter = null, weekFormatter = null) {
        if ((typeof year !== "number") || (year < 1970)) {
            throw ('year must be a number >= 1970');
        }
        if ((typeof month !== "number") || (month < 0) || (month > 11)) {
            throw ('month must be a number (Jan is 0)');
        }
        var weeks = [], week = [], i = 0, date = this.weekStartDate(new Date(year, month, 1));
        do {
            for (i = 0; i < 7; i++) {
                week.push(dayFormatter ? dayFormatter(date) : date);
                date = new Date(date.getTime());
                date.setDate(date.getDate() + 1);
            }
            weeks.push(weekFormatter ? weekFormatter(week) : week);
            week = [];
        } while ((date.getMonth() <= month) && (date.getFullYear() === year));
        return weeks;
    }
    monthDays(year, month) {
        var getDayOrZero = function getDayOrZero(date) {
            return date.getMonth() === month ? date : 0;
        };
        return this.monthDates(year, month, getDayOrZero);
    }
    monthText(year, month) {
        if (typeof year === "undefined") {
            var now = new Date();
            year = now.getFullYear();
            month = now.getMonth();
        }
        var getDayOrBlank = function getDayOrBlank(date) {
            var s = date.getMonth() === month ? date.getDate().toString() : "  ";
            while (s.length < 2)
                s = " " + s;
            return s;
        };
        var weeks = this.monthDates(year, month, getDayOrBlank, function (week) { return week.join(" "); });
        return weeks.join("\n");
    }
};
CalendarService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [])
], CalendarService);
// unclear what this actually does...
// const months = "JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC".split(" ");
// for (var i=0; i<months.length; i++) {
//     Calendar[months[i]] = i;
// }
/*!
 * calendar: a port of the calendar module from Python
 * Copyright(c) 2011 Luciano Ramalho <luciano@ramalho.org>
 * MIT Licensed
 */

const LANG_DE = {
    weekDays: [
        {
            letter: "S",
            short: "So.",
            full: "Sonntag"
        },
        {
            letter: "M",
            short: "Mo.",
            full: "Montag"
        },
        {
            letter: "D",
            short: "Di.",
            full: "Dienstag"
        },
        {
            letter: "M",
            short: "Mi.",
            full: "Mittwoch"
        },
        {
            letter: "D",
            short: "Do.",
            full: "Donnerstag"
        },
        {
            letter: "F",
            short: "Fr.",
            full: "Freitag"
        },
        {
            letter: "S",
            short: "Sa.",
            full: "Samstag"
        }
    ],
    months: [
        {
            short: "Jan.",
            full: "Januar"
        },
        {
            short: "Feb.",
            full: "Februar"
        },
        {
            short: "März",
            full: "März"
        },
        {
            short: "Apr.",
            full: "April"
        },
        {
            short: "Mai",
            full: "Mai"
        },
        {
            short: "Juni",
            full: "Juni"
        },
        {
            short: "Juli",
            full: "Juli"
        },
        {
            short: "Aug.",
            full: "August"
        },
        {
            short: "Sep.",
            full: "September"
        },
        {
            short: "Okt.",
            full: "Oktober"
        },
        {
            short: "Nov.",
            full: "November"
        },
        {
            short: "Dez.",
            full: "Dezember"
        }
    ]
};

let CalendarComponent = class CalendarComponent {
    constructor(calendarService) {
        this.dateChange = new EventEmitter();
        this.cancel = new EventEmitter();
        this.submit = new EventEmitter();
        this.today = new Date();
        this.calendarService = calendarService;
        this.dayNames = LANG_DE.weekDays;
        this.monthNames = LANG_DE.months;
    }
    get date() {
        return this.dateVal;
    }
    ;
    set date(val) {
        this.dateVal = val;
        this.dateChange.emit(val);
        this.updateDate(val);
    }
    ngOnInit() {
        this.date = new Date();
    }
    updateDate(date) {
        this.currentMonthNumber = date.getMonth();
        this.currentMonth = this.monthNames[this.currentMonthNumber];
        this.currentYear = date.getFullYear();
        this.currentDay = date.getDate();
        this.currentDayOfWeek = this.dayNames[date.getDay()];
        this.updateDisplay(this.currentYear, this.currentMonthNumber);
    }
    updateDisplay(year, month) {
        const calendarArray = this.calendarService.monthDays(year, month);
        this.displayDays = [].concat.apply([], calendarArray);
        this.displayMonthNumber = month;
        this.displayMonth = this.monthNames[month];
        this.displayYear = year;
    }
    equalsDate(date1, date2) {
        try {
            return date1.getFullYear() === date2.getFullYear() && date1.getMonth() === date2.getMonth() && date1.getDate() === date2.getDate();
        }
        catch (error) {
            return false;
        }
    }
    getDayBackgroundColor(day) {
        if (this.equalsDate(day, this.date)) {
            return 'day-background-selected';
        }
        else {
            return 'day-background-normal';
        }
    }
    getDayForegroundColor(day) {
        if (this.equalsDate(day, this.date)) {
            return 'day-foreground-selected';
        }
        else if (this.equalsDate(day, this.today)) {
            return 'day-foreground-today';
        }
        else {
            return 'day-foreground-normal';
        }
    }
    onToday() {
        this.date = this.today;
    }
    onPrevMonth() {
        if (this.displayMonthNumber > 0) {
            this.updateDisplay(this.displayYear, this.displayMonthNumber - 1);
        }
        else {
            this.updateDisplay(this.displayYear - 1, 11);
        }
        this.triggerAnimation('left');
    }
    onNextMonth() {
        if (this.displayMonthNumber < 11) {
            this.updateDisplay(this.displayYear, this.displayMonthNumber + 1);
        }
        else {
            this.updateDisplay(this.displayYear + 1, 0);
        }
        this.triggerAnimation('right');
    }
    onSelectDate(date) {
        this.date = date;
    }
    onCancel() {
        this.cancel.emit();
    }
    onOk() {
        this.submit.emit(this.date);
    }
    triggerAnimation(direction) {
        this.animate = direction;
        setTimeout(() => this.animate = 'reset', 230);
    }
};
__decorate([
    Output(),
    __metadata("design:type", Object)
], CalendarComponent.prototype, "dateChange", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date),
    __metadata("design:paramtypes", [Date])
], CalendarComponent.prototype, "date", null);
__decorate([
    Output(),
    __metadata("design:type", Object)
], CalendarComponent.prototype, "cancel", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], CalendarComponent.prototype, "submit", void 0);
CalendarComponent = __decorate([
    Component({
        selector: 'md-calendar',
        template: "<div class=\"header\">\n    <div class=\"year\">{{ currentYear }}</div>\n    <div class=\"date\">{{ currentDayOfWeek.short }}, {{ currentDay}}. {{ currentMonth.short }}</div>\n</div>\n<div class=\"nav\">\n    <button mat-icon-button class=\"left\" (click)=\"onPrevMonth()\">\n        <mat-icon>chevron_left</mat-icon>\n    </button>\n    <div class=\"title\">\n        <div [@calendarAnimation]=\"animate\">{{ displayMonth.full }} {{ displayYear }}</div>\n    </div>\n    <button mat-icon-button class=\"right\" (click)=\"onNextMonth()\">\n        <mat-icon>chevron_right</mat-icon>\n    </button>\n</div>\n<div class=\"content\">\n    <div class=\"labels\">\n        <div class=\"label\" *ngFor=\"let day of dayNames\">\n            {{ day.letter }}\n        </div>\n    </div>\n    <div [@calendarAnimation]=\"animate\" class=\"month\">\n        <div *ngFor=\"let day of displayDays\" class=\"day\" (click)=\"onSelectDate(day)\" [ngClass]=\"getDayBackgroundColor(day)\">\n            <span *ngIf=\"day != 0\" [ngClass]=\"getDayForegroundColor(day)\">\n                {{ day.getDate() }}\n              </span>\n        </div>\n    </div>\n</div>\n<div class=\"footer\">\n    <a mat-button (click)=\"onToday()\">Today</a>\n    <a mat-button (click)=\"onCancel()\">Cancel</a>\n    <a mat-button (click)=\"onOk()\">Ok</a>\n</div>\n",
        animations: [
            trigger('calendarAnimation', [
                transition('* => left', [
                    animate('0.225s ease-in-out', keyframes([
                        style({ transform: 'translateX(105%)', offset: 0.5 }),
                        style({ transform: 'translateX(-130%)', offset: 0.51 }),
                        style({ transform: 'translateX(0)', offset: 1 }),
                    ]))
                ]),
                transition('* => right', [
                    animate('0.225s ease-in-out', keyframes([
                        style({ transform: 'translateX(-105%)', offset: 0.5 }),
                        style({ transform: 'translateX(130%)', offset: 0.51 }),
                        style({ transform: 'translateX(0)', offset: 1 })
                    ]))
                ])
            ])
        ],
        styles: [".content,.footer,.header,.nav{font-family:Roboto,\"Segoe UI\",\"Helvetica Neue\",sans-serif}.header{padding:16px}.header .year{color:rgba(255,255,255,.7);font-size:14px;font-weight:500;margin-bottom:4px}.header .date{color:#fff;font-size:32px;font-weight:600}.nav{padding-top:8px;padding-bottom:8px;min-height:40px;overflow:hidden;position:relative}.nav .left{position:absolute;left:8px;z-index:100}.nav .right{position:absolute;right:8px;z-index:100}.nav .title{position:absolute;left:0;right:0;line-height:40px;text-align:center;font-size:14px;font-weight:600;overflow:hidden;z-index:10}.content{font-size:13px;padding-left:8px;padding-right:8px;width:18.2em;height:18.2em;overflow:hidden}.content .labels{display:-webkit-box;display:flex;-webkit-box-pack:center;justify-content:center;width:100%}.content .label{display:inline-block;width:2.2em;height:2.2em;margin:0 .2em;line-height:2.2em;text-align:center;color:rgba(0,0,0,.4)}.content .month{display:-webkit-box;display:flex;flex-flow:wrap;-webkit-box-pack:center;justify-content:center}.content .day{display:inline-block;width:2.2em;height:2.2em;margin:0 .2em .4em;border-radius:2.2em;line-height:2.2em;text-align:center;-webkit-transition:.37s;transition:.37s;cursor:pointer}.footer{text-align:right;padding:8px 8px 16px}.footer [md-button]{min-width:0;font-weight:600;text-transform:uppercase}"]
    }),
    __metadata("design:paramtypes", [CalendarService])
], CalendarComponent);

let DatePickerComponent = class DatePickerComponent {
    constructor(dialog) {
        this.dateChange = new EventEmitter();
        this.dialog = dialog;
        this.dayNames = LANG_DE.weekDays;
        this.monthNames = LANG_DE.months;
    }
    get date() {
        return this.dateVal;
    }
    ;
    set date(val) {
        this.dateVal = val;
        this.dateChange.emit(val);
        this.formattedDate = this.formatDate(val);
    }
    ngOnInit() {
        if (this.date === undefined) {
            this.date = new Date();
        }
    }
    openDialog() {
        let ref = this.dialog.open(CalendarComponent);
        // Workaround to update style of dialog which sits outside of the component
        let containerDiv = ref._overlayRef._pane.children[0];
        containerDiv.style['padding'] = '0';
        ref.componentInstance.submit.subscribe(result => {
            this.date = result;
            ref.close();
        });
        ref.componentInstance.cancel.subscribe(result => {
            ref.close();
        });
    }
    formatDate(date) {
        if (date === undefined) {
            return;
        }
        let dayOfWeek = this.dayNames[date.getDay()].short;
        let dayOfMonth = date.getDate();
        let month = this.monthNames[date.getMonth()].short;
        let year = date.getFullYear();
        return `${dayOfWeek}, ${dayOfMonth}. ${month} ${year}`;
    }
};
__decorate([
    Output(),
    __metadata("design:type", Object)
], DatePickerComponent.prototype, "dateChange", void 0);
__decorate([
    Input(),
    __metadata("design:type", Date),
    __metadata("design:paramtypes", [Date])
], DatePickerComponent.prototype, "date", null);
DatePickerComponent = __decorate([
    Component({
        selector: 'md-datepicker',
        template: "<span class=\"selected-date\" (click)=\"openDialog()\">{{formattedDate}}</span>",
        styles: [""]
    }),
    __metadata("design:paramtypes", [MatDialog])
], DatePickerComponent);

let DatePickerModule = class DatePickerModule {
};
DatePickerModule = __decorate([
    NgModule({
        declarations: [
            DatePickerComponent,
            CalendarComponent
        ],
        imports: [
            CommonModule,
            MatIconModule,
            MatButtonModule,
            MatDialogModule
        ],
        exports: [
            DatePickerComponent
        ],
        providers: [
            CalendarService
        ],
        entryComponents: [
            CalendarComponent
        ]
    })
], DatePickerModule);

export { DatePickerModule, DatePickerComponent as ɵa, CalendarComponent as ɵb, CalendarService as ɵc };
//# sourceMappingURL=angular-material_8-datepicker.js.map
